# truecluster/R/_DataDocu.R
# Documentation for truecluster datasets
# (C) 2000-2007 Dr. Jens Oehlschlgel
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###########################################################################


#! \name{centerring}
#! \docType{data}
#! \alias{centerring}
#! \title{Artificial dataset: centerring}
#! \description{
#! One spherical cluster surrounded by another ring-shaped cluster. Can be detected by density based cluster algorithms or single link.
#! }
#! \usage{data(centerring)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \references{
#! Oehlschlgel, J. (2006) \emph{Scalable robust clustering with model selection}.
#! }
#! \seealso{ \code{\link{spiral}}, \code{\link{SASmodeclus}} }
#! \keyword{datasets}

#! \name{spiral}
#! \docType{data}
#! \alias{spiral}
#! \title{Artificial dataset: spiral}
#! \description{
#! Two spiral-shaped clusters occupying the same topological area. Can be detected by density based cluster algorithms or single link.
#! }
#! \usage{data(spiral)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \references{
#! Oehlschlgel, J. (2006) \emph{Scalable robust clustering with model selection}.
#! }
#! \seealso{ \code{\link{centerring}}, \code{\link{SASmodeclus}} }
#! \keyword{datasets}

#! \name{symflipper}
#! \docType{data}
#! \alias{symflipper}
#! \title{Artificial dataset: symflipper}
#! \description{
#! Four convex clusters touching each other, double symmetry prevents unique 2-cluster solution.
#! }
#! \usage{data(symflipper)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \references{
#! Oehlschlgel, J. (2006) \emph{Scalable robust clustering with model selection}.
#! }
#! \seealso{ \code{\link{flipper}}, \code{\link{noflipper}} }
#! \keyword{datasets}

#! \name{SASmodeclus}
#! \docType{data}
#! \alias{SASmodeclus}
#! \title{Artificial dataset: SASmodeclus}
#! \description{
#! One elongated and two convex clusters that can be detected using density based cluster analysis.
#! }
#! \usage{data(SASmodeclus)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Similar configuration seen in handbook of commercial software package}
#! \references{
#! Oehlschlgel, J. (2006) \emph{Scalable robust clustering with model selection}.
#! }
#! \seealso{ \code{\link{centerring}}, \code{\link{spiral}}, \code{\link{conflict}}, \code{\link{hierarchic}} }
#! \keyword{datasets}

#! \name{noflipper}
#! \docType{data}
#! \alias{noflipper}
#! \title{Artificial dataset: noflipper}
#! \description{
#! Four convex clusters with a pairwise grouping such that a 2 cluster solution is stable as well.
#! }
#! \usage{data(noflipper)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \references{
#! Oehlschlgel, J. (2006) \emph{Scalable robust clustering with model selection}.
#! }
#! \seealso{ \code{\link{flipper}}, \code{\link{symflipper}}, \code{\link{hierarchic}} }
#! \keyword{datasets}

#! \name{hierarchic}
#! \docType{data}
#! \alias{hierarchic}
#! \title{Artificial dataset: hierarchic}
#! \description{
#! One big and two small clusters, where one of the small clusters has the same structure again. Thus both, a 3-cluster and a 5-cluster solution have some justification.
#! }
#! \usage{data(hierarchic)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \seealso{ \code{\link{conflict}}, \code{\link{noflipper}}, \code{\link{cophenetic}}  }
#! \keyword{datasets}

#! \name{flipper}
#! \docType{data}
#! \alias{flipper}
#! \title{Artificial dataset: flipper}
#! \description{
#! Four convex clusters without a pairwise grouping such that a 2 cluster solution is not stable.
#! }
#! \usage{data(flipper)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \references{
#! Oehlschlgel, J. (2006) \emph{Scalable robust clustering with model selection}.
#! }
#! \seealso{ \code{\link{noflipper}}, \code{\link{symflipper}} }
#! \keyword{datasets}

#! \name{extremegroup}
#! \docType{data}
#! \alias{extremegroup}
#! \title{Artificial dataset: extremegroup}
#! \description{
#! Two convex clusters with a third small very outlying cluster.
#! }
#! \usage{data(extremegroup)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \seealso{ \code{\link{SASmodeclus}}, \code{\link{hierarchic}} }
#! \keyword{datasets}

#! \name{cophenetic}
#! \docType{data}
#! \alias{cophenetic}
#! \title{Artificial dataset: cophenetic}
#! \description{
#! Five cluster with a perfect cophenetic structure: there is a unique way to agglomerate those five. Some procedures fail to recognize five clusters, because 2 of those are very close to each other.
#! }
#! \usage{data(cophenetic)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \seealso{ \code{\link{hierarchic}}, \code{\link{noflipper}}, \code{\link{flipper}}, \code{\link{extremegroup}} }
#! \keyword{datasets}

#! \name{conflict}
#! \docType{data}
#! \alias{conflict}
#! \title{Artificial dataset: conflict}
#! \description{
#! This dataset contains two elongated clusters, from a density based perspective. However, from a convex perspective (not sphering the space) we would rather find that 2 halves of those belong together (split in the other dimension).
#! }
#! \usage{data(conflict)}
#! \format{A dataframe with columns x, y and cluster}
#! \source{Artificial}
#! \references{
#! Oehlschlgel, J. (2006) \emph{Scalable robust clustering with model selection}.
#! }
#! \seealso{ \code{\link{hierarchic}}, \code{\link{noflipper}}, \code{\link{flipper}}, \code{\link{SASmodeclus}}  }
#! \keyword{datasets}

